#include <OneWire.h> 
#include <DallasTemperature.h>
#include <SPI.h>

#define PIN_THERMOMETER 2
#define PIN_DISPLAY_RST 3

const int digits[16] = {
  0x3F, 0x06, 0x5B, 0x4F,
  0x66, 0x6D, 0x7D, 0x07,
  0x7F, 0x6F, 0x77, 0x7C,
  0x39, 0x5E, 0x79, 0x71
};

OneWire oneWire(PIN_THERMOMETER);
DallasTemperature sensors(&oneWire);

int temperature = 0;
int minTemp = 1000;
int maxTemp = -1000;

byte display[12] = {
  0x00, 0x00, 0x00,
  0x00, 0x00, 0x00,
  0x00, 0x00, 0x00,
  0x00, 0x00, 0x00
};

void setup() {
  SPI.begin();
  sensors.begin();

  pinMode(PIN_DISPLAY_RST, OUTPUT);
  digitalWrite(PIN_DISPLAY_RST, HIGH);
  delay(1);
  digitalWrite(PIN_DISPLAY_RST, LOW);

  for (int i = 0; i < 10; i ++) {
    sensors.requestTemperatures();
    delay(1);
  }
}

void loop() {  
  updateTemperature();
  updateDisplay();

  for (int k = 0; k < 1000; k ++) {
    for (int i = 0; i < 12; i ++) {
      SPI.transfer(display[i]);
      delay(1);
    }
  }
}


void updateTemperature() {
  sensors.requestTemperatures();
  temperature = (int)(sensors.getTempCByIndex(0) * 10) % 1000;
  minTemp = min(minTemp, temperature);
  maxTemp = max(maxTemp, temperature);
}


void updateDisplay() {
  display[11] = digits[(temperature / 100) % 10];
  display[1] = digits[(temperature / 10) % 10] + 0x80;
  display[2] = digits[temperature % 10];

  display[3] = digits[(minTemp / 100) % 10];
  display[4] = digits[(minTemp / 10) % 10] + 0x80;
  display[5] = digits[minTemp % 10];

  display[6] = digits[(maxTemp / 100) % 10];
  display[7] = digits[(maxTemp / 10) % 10] + 0x80;
  display[8] = digits[maxTemp % 10];
}
